/*******************************************************************************
* File Name: Rin.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Rin.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 Rin__PORT == 15 && ((Rin__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: Rin_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void Rin_Write(uint8 value) 
{
    uint8 staticBits = (Rin_DR & (uint8)(~Rin_MASK));
    Rin_DR = staticBits | ((uint8)(value << Rin_SHIFT) & Rin_MASK);
}


/*******************************************************************************
* Function Name: Rin_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  Rin_DM_STRONG     Strong Drive 
*  Rin_DM_OD_HI      Open Drain, Drives High 
*  Rin_DM_OD_LO      Open Drain, Drives Low 
*  Rin_DM_RES_UP     Resistive Pull Up 
*  Rin_DM_RES_DWN    Resistive Pull Down 
*  Rin_DM_RES_UPDWN  Resistive Pull Up/Down 
*  Rin_DM_DIG_HIZ    High Impedance Digital 
*  Rin_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void Rin_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(Rin_0, mode);
}


/*******************************************************************************
* Function Name: Rin_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Rin_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Rin_Read(void) 
{
    return (Rin_PS & Rin_MASK) >> Rin_SHIFT;
}


/*******************************************************************************
* Function Name: Rin_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Rin_ReadDataReg(void) 
{
    return (Rin_DR & Rin_MASK) >> Rin_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Rin_INTSTAT) 

    /*******************************************************************************
    * Function Name: Rin_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Rin_ClearInterrupt(void) 
    {
        return (Rin_INTSTAT & Rin_MASK) >> Rin_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
